abacusai.test_point_predictions — AbacusAI documentation

# `abacusai.test_point_predictions`

## Module Contents

### Classes

`TestPointPredictions` | Test Point Predictions

class abacusai.test_point_predictions.TestPointPredictions(client, count=None, columns=None, data=None, metricsColumns=None, summarizedMetrics=None, errorDescription=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Test Point Predictions

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - count (int) – Count of total rows in the preview data for the SQL.

    - columns (list) – The returned columns

    - data (list) – A list of data rows, each represented as a list.

    - metricsColumns (list) – The columns that are the metrics.

    - summarizedMetrics (dict) – A map between the problem type metrics and the mean of the results matching the query

    - errorDescription (str) – Description of an error in case of failure.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict